# QW TCP mode
# this is a python3 sample code for QW TCP like EM-38A-TCP or EM-18A-TCP Audio Repeater

import socket
# ~ import time
def connect_qw_tcp(_device_ip, _port):
    after_idle_sec = 15
    interval_sec=10
    max_fails=5
    sock = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
    sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, after_idle_sec)
    sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, interval_sec)
    sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPCNT, max_fails)
    sock.settimeout(60)
    sock.connect((_device_ip, _port))
    return sock

def control_qw_tcp(_command, _device_ip, _port):
    recv_bytes = bytes()
    s = connect_qw_tcp(_device_ip, _port)  # connect before loop
    for c in _command:
        try:
            s.send(bytes(c, 'utf-8'))
            print('send: {}'.format(c))
            device_feedback = s.recv(4)
            print('recv: {}'.format(device_feedback))
            recv_bytes = recv_bytes + device_feedback
        except Exception as e:
            print('Warning:{}'.format(e))
    print('close qw socket, back to standby mode')
    s.close()
    try:
        recv_str = recv_bytes.decode("utf-8")
    except:  # can not decode by utf-8 bytes
        print('recv_bytes is not unicode, value need convert before return')
        value_int = int.from_bytes(recv_bytes, byteorder='big')  # like 255, convert bytes to int
        value_bin = bin(value_int)
        recv_str = str(value_bin)[2:]  # 11111111
    print('total recv: {}'.format(recv_str))
    return recv_str


def main():
  device_ip = '169.254.73.66'
  port = 9000
  command = 'F001'
  control_qw_tcp(command, device_ip, port)

if __name__ == "__main__":
  main()

